Class: Aws::MPA::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MPA::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mpa/client.rb,
sig/client.rbs
Overview
An API client for MPA. To construct a client, you need to configure a :region and :credentials.
client = Aws::MPA::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelSessionResponseSuccess, _CreateApprovalTeamResponseSuccess, _CreateIdentitySourceResponseSuccess, _DeleteInactiveApprovalTeamVersionResponseSuccess, _GetApprovalTeamResponseSuccess, _GetIdentitySourceResponseSuccess, _GetPolicyVersionResponseSuccess, _GetResourcePolicyResponseSuccess, _GetSessionResponseSuccess, _ListApprovalTeamsResponseSuccess, _ListIdentitySourcesResponseSuccess, _ListPoliciesResponseSuccess, _ListPolicyVersionsResponseSuccess, _ListResourcePoliciesResponseSuccess, _ListSessionsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartActiveApprovalTeamDeletionResponseSuccess, _StartApprovalTeamBaselineResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApprovalTeamResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_session(params = {}) ⇒ Struct
Cancels an approval session.
-
#create_approval_team(params = {}) ⇒ Types::CreateApprovalTeamResponse
Creates a new approval team.
-
#create_identity_source(params = {}) ⇒ Types::CreateIdentitySourceResponse
Creates a new identity source.
-
#delete_identity_source(params = {}) ⇒ Struct
Deletes an identity source.
-
#delete_inactive_approval_team_version(params = {}) ⇒ Struct
Deletes an inactive approval team.
-
#get_approval_team(params = {}) ⇒ Types::GetApprovalTeamResponse
Returns details for an approval team.
-
#get_identity_source(params = {}) ⇒ Types::GetIdentitySourceResponse
Returns details for an identity source.
-
#get_policy_version(params = {}) ⇒ Types::GetPolicyVersionResponse
Returns details for the version of a policy.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns details about a policy for a resource.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Returns details for an approval session.
-
#list_approval_teams(params = {}) ⇒ Types::ListApprovalTeamsResponse
Returns a list of approval teams.
-
#list_identity_sources(params = {}) ⇒ Types::ListIdentitySourcesResponse
Returns a list of identity sources.
-
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Returns a list of policies.
-
#list_policy_versions(params = {}) ⇒ Types::ListPolicyVersionsResponse
Returns a list of the versions for policies.
-
#list_resource_policies(params = {}) ⇒ Types::ListResourcePoliciesResponse
Returns a list of policies for a resource.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Returns a list of approval sessions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags for a resource.
-
#start_active_approval_team_deletion(params = {}) ⇒ Types::StartActiveApprovalTeamDeletionResponse
Starts the deletion process for an active approval team.
-
#start_approval_team_baseline(params = {}) ⇒ Types::StartApprovalTeamBaselineResponse
Starts a baseline session for specified approvers on an
ACTIVEapproval team. -
#tag_resource(params = {}) ⇒ Struct
Creates or updates a resource tag.
-
#untag_resource(params = {}) ⇒ Struct
Removes a resource tag.
-
#update_approval_team(params = {}) ⇒ Types::UpdateApprovalTeamResponse
Updates an approval team.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mpa/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1642 1643 1644 |
# File 'lib/aws-sdk-mpa/client.rb', line 1642 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1645 1646 1647 |
# File 'lib/aws-sdk-mpa/client.rb', line 1645 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 |
# File 'lib/aws-sdk-mpa/client.rb', line 1615 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MPA') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mpa' context[:gem_version] = '1.19.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_session(params = {}) ⇒ Struct
Cancels an approval session. For more information, see Session in the Multi-party approval User Guide.
85 |
# File 'sig/client.rbs', line 85
def cancel_session: (
|
#create_approval_team(params = {}) ⇒ Types::CreateApprovalTeamResponse
Creates a new approval team. For more information, see Approval team in the Multi-party approval User Guide.
98 |
# File 'sig/client.rbs', line 98
def create_approval_team: (
|
#create_identity_source(params = {}) ⇒ Types::CreateIdentitySourceResponse
Creates a new identity source. For more information, see Identity Source in the Multi-party approval User Guide.
129 |
# File 'sig/client.rbs', line 129
def create_identity_source: (
|
#delete_identity_source(params = {}) ⇒ Struct
Deletes an identity source. For more information, see Identity Source in the Multi-party approval User Guide.
142 |
# File 'sig/client.rbs', line 142
def delete_identity_source: (
|
#delete_inactive_approval_team_version(params = {}) ⇒ Struct
Deletes an inactive approval team. For more information, see Team health in the Multi-party approval User Guide.
You can also use this operation to delete a team draft. For more information, see Interacting with drafts in the Multi-party approval User Guide.
151 |
# File 'sig/client.rbs', line 151
def delete_inactive_approval_team_version: (
|
#get_approval_team(params = {}) ⇒ Types::GetApprovalTeamResponse
Returns details for an approval team.
176 |
# File 'sig/client.rbs', line 176
def get_approval_team: (
|
#get_identity_source(params = {}) ⇒ Types::GetIdentitySourceResponse
Returns details for an identity source. For more information, see Identity Source in the Multi-party approval User Guide.
192 |
# File 'sig/client.rbs', line 192
def get_identity_source: (
|
#get_policy_version(params = {}) ⇒ Types::GetPolicyVersionResponse
Returns details for the version of a policy. Policies define the permissions for team resources.
202 |
# File 'sig/client.rbs', line 202
def get_policy_version: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns details about a policy for a resource.
216 |
# File 'sig/client.rbs', line 216
def get_resource_policy: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Returns details for an approval session. For more information, see Session in the Multi-party approval User Guide.
251 |
# File 'sig/client.rbs', line 251
def get_session: (
|
#list_approval_teams(params = {}) ⇒ Types::ListApprovalTeamsResponse
Returns a list of approval teams.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
262 |
# File 'sig/client.rbs', line 262
def list_approval_teams: (
|
#list_identity_sources(params = {}) ⇒ Types::ListIdentitySourcesResponse
Returns a list of identity sources. For more information, see Identity Source in the Multi-party approval User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
274 |
# File 'sig/client.rbs', line 274
def list_identity_sources: (
|
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Returns a list of policies. Policies define the permissions for team resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
286 |
# File 'sig/client.rbs', line 286
def list_policies: (
|
#list_policy_versions(params = {}) ⇒ Types::ListPolicyVersionsResponse
Returns a list of the versions for policies. Policies define the permissions for team resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_policy_versions: (
|
#list_resource_policies(params = {}) ⇒ Types::ListResourcePoliciesResponse
Returns a list of policies for a resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
311 |
# File 'sig/client.rbs', line 311
def list_resource_policies: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Returns a list of approval sessions. For more information, see Session in the Multi-party approval User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
324 |
# File 'sig/client.rbs', line 324
def list_sessions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags for a resource.
343 |
# File 'sig/client.rbs', line 343
def list_tags_for_resource: (
|
#start_active_approval_team_deletion(params = {}) ⇒ Types::StartActiveApprovalTeamDeletionResponse
Starts the deletion process for an active approval team.
Requests to delete an active team must be approved by the team.
354 |
# File 'sig/client.rbs', line 354
def start_active_approval_team_deletion: (
|
#start_approval_team_baseline(params = {}) ⇒ Types::StartApprovalTeamBaselineResponse
Starts a baseline session for specified approvers on an ACTIVE
approval team.
365 |
# File 'sig/client.rbs', line 365
def start_approval_team_baseline: (
|
#tag_resource(params = {}) ⇒ Struct
Creates or updates a resource tag. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
375 |
# File 'sig/client.rbs', line 375
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a resource tag. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
385 |
# File 'sig/client.rbs', line 385
def untag_resource: (
|
#update_approval_team(params = {}) ⇒ Types::UpdateApprovalTeamResponse
Updates an approval team. You can request to update the team description, approval threshold, and approvers in the team.
Updates to an active team must be approved by the team.
396 |
# File 'sig/client.rbs', line 396
def update_approval_team: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1635 1636 1637 |
# File 'lib/aws-sdk-mpa/client.rb', line 1635 def waiter_names [] end |