Class: Aws::MPA::Types::GetApprovalTeamResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mpa/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#approval_strategyTypes::ApprovalStrategyResponse

An ‘ApprovalStrategyResponse` object. Contains details for how the team grants approval.



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#approversArray<Types::GetApprovalTeamResponseApprover>

An array of ‘GetApprovalTeamResponseApprover ` objects. Contains details for the approvers in the team.



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#arnString

Amazon Resource Name (ARN) for the team.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#creation_timeTime

Timestamp when the team was created.

Returns:

  • (Time)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

Description for the team.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_update_timeTime

Timestamp when the team was last updated.

Returns:

  • (Time)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

Name of the approval team.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#number_of_approversInteger

Total number of approvers in the team.

Returns:

  • (Integer)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#pending_updateTypes::PendingUpdate

A ‘PendingUpdate` object. Contains details for the pending updates for the team, if applicable.



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#policiesArray<Types::PolicyReference>

An array of ‘PolicyReference` objects. Contains a list of policies that define the permissions for team resources.

Returns:



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

Status for the team. For more information, see [Team health] in the *Multi-party approval User Guide*.

[1]: docs.aws.amazon.com/mpa/latest/userguide/mpa-health.html

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#status_codeString

Status code for the approval team. For more information, see [Team health] in the *Multi-party approval User Guide*.

[1]: docs.aws.amazon.com/mpa/latest/userguide/mpa-health.html

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#status_messageString

Message describing the status for the team.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#update_session_arnString

Amazon Resource Name (ARN) for the session.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#version_idString

Version ID for the team.

Returns:

  • (String)


475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-mpa/types.rb', line 475

class GetApprovalTeamResponse < Struct.new(
  :creation_time,
  :approval_strategy,
  :number_of_approvers,
  :approvers,
  :arn,
  :description,
  :name,
  :status,
  :status_code,
  :status_message,
  :update_session_arn,
  :version_id,
  :policies,
  :last_update_time,
  :pending_update)
  SENSITIVE = [:description]
  include Aws::Structure
end