Class: Aws::MPA::Types::GetApprovalTeamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MPA::Types::GetApprovalTeamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mpa/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#approval_strategy ⇒ Types::ApprovalStrategyResponse
An ‘ApprovalStrategyResponse` object.
-
#approvers ⇒ Array<Types::GetApprovalTeamResponseApprover>
An array of ‘GetApprovalTeamResponseApprover ` objects.
-
#arn ⇒ String
Amazon Resource Name (ARN) for the team.
-
#creation_time ⇒ Time
Timestamp when the team was created.
-
#description ⇒ String
Description for the team.
-
#last_update_time ⇒ Time
Timestamp when the team was last updated.
-
#name ⇒ String
Name of the approval team.
-
#number_of_approvers ⇒ Integer
Total number of approvers in the team.
-
#pending_update ⇒ Types::PendingUpdate
A ‘PendingUpdate` object.
-
#policies ⇒ Array<Types::PolicyReference>
An array of ‘PolicyReference` objects.
-
#status ⇒ String
Status for the team.
-
#status_code ⇒ String
Status code for the approval team.
-
#status_message ⇒ String
Message describing the status for the team.
-
#update_session_arn ⇒ String
Amazon Resource Name (ARN) for the session.
-
#version_id ⇒ String
Version ID for the team.
Instance Attribute Details
#approval_strategy ⇒ Types::ApprovalStrategyResponse
An ‘ApprovalStrategyResponse` object. Contains details for how the team grants approval.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#approvers ⇒ Array<Types::GetApprovalTeamResponseApprover>
An array of ‘GetApprovalTeamResponseApprover ` objects. Contains details for the approvers in the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#arn ⇒ String
Amazon Resource Name (ARN) for the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#creation_time ⇒ Time
Timestamp when the team was created.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
Description for the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#last_update_time ⇒ Time
Timestamp when the team was last updated.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
Name of the approval team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#number_of_approvers ⇒ Integer
Total number of approvers in the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#pending_update ⇒ Types::PendingUpdate
A ‘PendingUpdate` object. Contains details for the pending updates for the team, if applicable.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#policies ⇒ Array<Types::PolicyReference>
An array of ‘PolicyReference` objects. Contains a list of policies that define the permissions for team resources.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
Status for the team. For more information, see [Team health] in the *Multi-party approval User Guide*.
[1]: docs.aws.amazon.com/mpa/latest/userguide/mpa-health.html
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#status_code ⇒ String
Status code for the approval team. For more information, see [Team health] in the *Multi-party approval User Guide*.
[1]: docs.aws.amazon.com/mpa/latest/userguide/mpa-health.html
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#status_message ⇒ String
Message describing the status for the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#update_session_arn ⇒ String
Amazon Resource Name (ARN) for the session.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |
#version_id ⇒ String
Version ID for the team.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/aws-sdk-mpa/types.rb', line 475 class GetApprovalTeamResponse < Struct.new( :creation_time, :approval_strategy, :number_of_approvers, :approvers, :arn, :description, :name, :status, :status_code, :status_message, :update_session_arn, :version_id, :policies, :last_update_time, :pending_update) SENSITIVE = [:description] include Aws::Structure end |